Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(495)

Unified Diff: third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceClipper.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceClipper.cpp
diff --git a/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceClipper.cpp b/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceClipper.cpp
index 94338f814f1c2371b20507c39dfb9529055ef6c8..2072bcaa97c3b9a2236fdb90464dcae03b0ab829 100644
--- a/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceClipper.cpp
+++ b/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceClipper.cpp
@@ -170,10 +170,10 @@ sk_sp<const SkPicture> LayoutSVGResourceClipper::createContentPicture() {
if (m_clipContentPicture)
return m_clipContentPicture;
// Using strokeBoundingBox (instead of
// paintInvalidationRectInLocalSVGCoordinates) to avoid the intersection with
// local clips/mask, which may yield incorrect results when mixing
// objectBoundingBox and userSpaceOnUse units (http://crbug.com/294900).
FloatRect bounds = strokeBoundingBox();
SkPictureBuilder pictureBuilder(bounds, nullptr, nullptr);
@@ -250,7 +250,7 @@ void LayoutSVGResourceClipper::calculateLocalClipBounds() {
continue;
m_localClipBounds.unite(layoutObject->localToSVGParentTransform().mapRect(
- layoutObject->paintInvalidationRectInLocalSVGCoordinates()));
+ layoutObject->visualRectInLocalSVGCoordinates()));
}
}
@@ -170,10 +170,10 @@ sk_sp<const SkPicture> LayoutSVGResourceClipper::createContentPicture() {
if (m_clipContentPicture)
return m_clipContentPicture;
- // Using strokeBoundingBox (instead of
- // paintInvalidationRectInLocalSVGCoordinates) to avoid the intersection with
- // local clips/mask, which may yield incorrect results when mixing
- // objectBoundingBox and userSpaceOnUse units (http://crbug.com/294900).
+ // Using strokeBoundingBox (instead of visualRectInLocalSVGCoordinates) to
+ // avoid the intersection with local clips/mask, which may yield incorrect
+ // results when mixing objectBoundingBox and userSpaceOnUse units
+ // (http://crbug.com/294900).
FloatRect bounds = strokeBoundingBox();
SkPictureBuilder pictureBuilder(bounds, nullptr, nullptr);

Powered by Google App Engine
This is Rietveld 408576698